/*
    Copyright (C) 2000  Mark W. Webb (markwebb@adelphia.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/



import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.io.*;
import java.security.MessageDigest;

public class MainWindow implements ActionListener
{
  static JFrame frame;
  JMenu file, view, tools, help;
  JMenuItem connect, disconnect, exit;
  JMenuItem find, library, transfer, hotlist;
  JMenuItem newuser, options;
  JMenuItem aboutscour, scourhelp;
  JButton findmedia, medialibrary, filetransfer, hotlst;
  static String FIND = "Find";
  static String LIBRARY = "Library";
  static String TRANSFER = "Transfer";
  static String HOTLIST = "HotList";
  static CardLayout cardlayout;
  static JPanel card;
  static SearchPanel searchpanel;
  static LibraryPanel librarypanel;
  static TransferPanel transferpanel;
  static HotListPanel hotlistpanel;
  
  public MainWindow( String username )
  {
    frame = new JFrame( "Java Scour Agent" );
    
    frame.setJMenuBar( getMenuBar( true ) );
    frame.getContentPane().add( getToolBar(), BorderLayout.WEST );

    card = new JPanel();
    cardlayout = new CardLayout();
    card.setLayout( cardlayout );
    
    librarypanel = new LibraryPanel();
    transferpanel = new TransferPanel();
    hotlistpanel = new HotListPanel();
    searchpanel = new SearchPanel();
     
    card.add( searchpanel, FIND );
    card.add( librarypanel, LIBRARY );
    card.add( transferpanel, TRANSFER );
    card.add( hotlistpanel, HOTLIST );
    
    frame.getContentPane().add( card, BorderLayout.CENTER );

    frame.addWindowListener(new WindowAdapter() {
        public void windowActivated(WindowEvent e) {}
        public void windowClosed(WindowEvent e) {}
        public void windowClosing(WindowEvent e) {System.exit(0);}
        public void windowDeactivated(WindowEvent e) {}
        public void windowDeiconified(WindowEvent e) {}
        public void windowIconified(WindowEvent e) {}
        public void windowOpened(WindowEvent e) {}
      });

    frame.pack();
    frame.setVisible( true );
  }

  public static SearchPanel getSearchPanel(){ return searchpanel; }
  public static LibraryPanel getLibraryPanel(){ return librarypanel; }
  public static TransferPanel getTransferPanel(){ return transferpanel; }
  public static HotListPanel getHotListPanel(){ return hotlistpanel; }
  public static JFrame getFrame(){ return frame; }
  
  public static void showPanel( String panel )
  {
    cardlayout.show( card, panel );
  }
    
  private JToolBar getToolBar()
  {
    JToolBar tb = new JToolBar( JToolBar.VERTICAL );
    findmedia = new JButton( new ImageIcon( "find.gif" ));
    findmedia.setToolTipText( "Find files" );
    findmedia.addActionListener( this );
    tb.add( findmedia );
    medialibrary = new JButton( new ImageIcon( "library.gif" ));
    medialibrary.setToolTipText( "Media Library" );
    medialibrary.addActionListener( this );
    tb.add( medialibrary );
    filetransfer = new JButton( new ImageIcon( "filetransfer.gif" ));
    filetransfer.setToolTipText( "File Transfer Status" );
    filetransfer.addActionListener( this );
    tb.add( filetransfer );
    hotlst = new JButton( new ImageIcon( "hotlist.gif" ));
    hotlst.setToolTipText( "User Hot List" );
    hotlst.addActionListener( this );
    tb.add( hotlst );
    
    return tb;
  }
  
  private JMenuBar getMenuBar(boolean isloggedin)
  {
    JMenuBar mb = new JMenuBar();
    file = new JMenu( "File" );
    connect = new JMenuItem( "Connect" );
    connect.addActionListener( this );
    connect.setEnabled( isloggedin );
    file.add( connect );
    disconnect = new JMenuItem( "Disconnect" );
    disconnect.addActionListener( this );
    disconnect.setEnabled( !isloggedin );
    file.add( disconnect );
    exit = new JMenuItem( "Exit" );
    exit.addActionListener( this );
    file.add( exit );
    mb.add( file );

    view = new JMenu( "View" );
    find = new JMenuItem( "Find Media" );
    find.addActionListener( this );
    view.add( find );
    library = new JMenuItem( "Media Library" );
    library.addActionListener( this );
    view.add( library );
    transfer = new JMenuItem( "File Transfer" );
    transfer.addActionListener( this );
    view.add( transfer );
    hotlist = new JMenuItem( "Hotlist" );
    hotlist.addActionListener( this );
    view.add( hotlist );
    mb.add( view );
    
    tools = new JMenu( "Tools" );
    newuser = new JMenuItem( "Add New User" );
    newuser.addActionListener( this );
    tools.add( newuser );
    options = new JMenuItem( "Options" );
    options.addActionListener( this );
    tools.add( options );
    mb.add( tools );
    
    help = new JMenu( "Help" );
    aboutscour = new JMenuItem( "About JavaScour" );
    aboutscour.addActionListener( this );
    help.add( aboutscour );
    scourhelp = new JMenuItem( "JavaScour Help" );
    scourhelp.addActionListener( this );
    help.add( scourhelp );
    mb.add( help );
    
    return mb;
  }

  public void actionPerformed( ActionEvent e )
  {
//      System.out.println(e.getActionCommand());
    if( e.getSource() == exit )
      {
	try{
	  FileInputStream fis = new FileInputStream( System.getProperty("user.home") + 
						     System.getProperty("file.separator") + ".javascour" );
	  ObjectInputStream ois = new ObjectInputStream( fis );
	  StartUpInfo si = (StartUpInfo)ois.readObject();

	  FileOutputStream fos = new FileOutputStream( System.getProperty("user.home") + 
						       System.getProperty("file.separator") + ".javascour");
	  ObjectOutputStream oos = new ObjectOutputStream( fos );
	  si.setHotlist( hotlistpanel.getUsers() );
	  
	  oos.writeObject( si );
	}catch(Exception ex){
	  JOptionPane.showMessageDialog( frame, "There was a problem reported while reading startup file.\n" + 
					 ex, "Error", JOptionPane.ERROR_MESSAGE );
	}
	System.exit(0);
      }
    else if( e.getSource() == findmedia )
      showPanel( FIND );
    else if( e.getSource() == medialibrary )
      showPanel( LIBRARY );
    else if( e.getSource() == filetransfer )
      showPanel( TRANSFER );
    else if( e.getSource() == hotlst )
      showPanel( HOTLIST );
  }
}
